==> react-bubble-ui-1.1.2.tgz: package/README.md <==
# React-Bubble-UI 🔮

A highly configurable Bubble UI React.js component, similar to the iconic Apple Watch app layout.

[![NPM](https://img.shields.io/npm/v/react-bubble-ui.svg)](https://www.npmjs.com/package/react-bubble-ui) [![JavaScript Style Guide](https://img.shields.io/badge/code_style-standard-brightgreen.svg)](https://standardjs.com)

<img src="./example/public/demo.gif" style="border-radius: 30px"/>

## Install

```bash
npm install --save react-bubble-ui
```

## Interactive Demo

Interact with a live demo to configure to UI to your liking.

[**Experience Demo**](https://blakesanie.github.io/React-Bubble-UI/#/demo)

## Thorough Documentation

Understand how to apply the component's high confirgurability to your design.

[**Read Docs**](https://blakesanie.github.io/React-Bubble-UI/#/docs)

## Contributing

I highly encourage you to help improve this package further through the following steps:

1. Fork this repository, and clone your fork
2. Create an upstream remote and sync your local copy
3. Branch off for the new feature
4. Contribute the feature (write the code)
5. Push to your (personal) origin repository
6. Create a Pull Request

## Author

This package was created by [Blake Sanie](https://github.com/blakesanie) in 2020.

Like what you see? [View his other projects 📱 ](https://blakesanie.com/cs), [read his blog 💻 ](https://blakesanie.medium.com), or [buy him a coffee ☕](https://paypal.me/blakesanie?locale.x=en_US).

## License

MIT © [blakesanie](https://github.com/blakesanie)

==> react-bubble-ui-v2-0.1.2.tgz: package/README.md <==
# React-Bubble-UI 🔮

A highly configurable Bubble UI React.js component, similar to the iconic Apple Watch app layout.

[![NPM](https://img.shields.io/npm/v/react-bubble-ui.svg)](https://www.npmjs.com/package/react-bubble-ui-v2) [![JavaScript Style Guide](https://img.shields.io/badge/code_style-standard-brightgreen.svg)](https://standardjs.com)

<img src="https://raw.githubusercontent.com/blakesanie/React-Bubble-UI/main/example/public/demo.gif" style="border-radius: 30px"/>

## Install

```bash
npm install --save react-bubble-ui-v2
```

## Interactive Demo

Interact with a live demo to configure to UI to your liking.

[**Experience Demo**](https://blakesanie.github.io/React-Bubble-UI/#/demo)

## Thorough Documentation

Understand how to apply the component's high confirgurability to your design.

[**Read Docs**](https://blakesanie.github.io/React-Bubble-UI/#/docs)

## Contributing

I highly encourage you to help improve this package further through the following steps:

1. Fork this repository, and clone your fork
2. Create an upstream remote and sync your local copy
3. Branch off for the new feature
4. Contribute the feature (write the code)
5. Push to your (personal) origin repository
6. Create a Pull Request

## Author

This package was created by [Blake Sanie](https://github.com/blakesanie) in 2020.

Like what you see? [View his other projects 📱 ](https://blakesanie.com/cs), [read his blog 💻 ](https://blakesanie.medium.com), or [buy him a coffee ☕](https://paypal.me/blakesanie?locale.x=en_US).

## License

MIT © [blakesanie](https://github.com/blakesanie)
